==> ace_5.6.3.orig.tar.gz: ACE_wrappers/TAO/tao/EndpointPolicy/EndpointPolicy.h <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file   EndpointPolicy.h
 *
 *  $Id: EndpointPolicy.h 79255 2007-08-08 10:19:38Z johnnyw $
 *
 *  @author  Yan Dai <dai_y@ociweb.com>
 */
//=============================================================================


#ifndef TAO_ENDPOINTPOLICY_H
#define TAO_ENDPOINTPOLICY_H

#include /**/ "ace/pre.h"

#include "tao/EndpointPolicy/EndpointPolicy_Export.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "tao/PI/PI.h"
#include "tao/Versioned_Namespace.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

class TAO_EndpointPolicy_Export TAO_EndpointPolicy_Initializer
  : public ACE_Service_Object
{
public:
  /// Used to force the initialization of the ORB code.
  static int static_init (void);

  /// Initialize the Endpoint Policy loader hooks.
  virtual int init (int argc, ACE_TCHAR* []);
};

static int
TAO_Requires_EndpointPolicy_Initializer = TAO_EndpointPolicy_Initializer::static_init ();

TAO_END_VERSIONED_NAMESPACE_DECL

ACE_STATIC_SVC_DECLARE_EXPORT (TAO_EndpointPolicy, TAO_EndpointPolicy_Initializer)
ACE_FACTORY_DECLARE (TAO_EndpointPolicy, TAO_EndpointPolicy_Initializer)

#include /**/ "ace/post.h"

#define TAO_ENDPOINTPOLICY_SAFE_INCLUDE
#include "tao/EndpointPolicy/EndpointPolicyC.h"
#include "tao/EndpointPolicy/EndpointPolicyA.h"
#include "tao/IOP_IORC.h"
#include "tao/AnyTypeCode/Any.h"
#undef TAO_ENDPOINTPOLICY_SAFE_INCLUDE

#endif /* TAO_ENDPOINTPOLICY_H */

==> ace_6.0.1.orig.tar.gz: ACE_wrappers/TAO/tao/EndpointPolicy/EndpointPolicy.h <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file   EndpointPolicy.h
 *
 *  $Id: EndpointPolicy.h 84281 2009-01-30 15:01:17Z wotte $
 *
 *  @author  Yan Dai <dai_y@ociweb.com>
 */
//=============================================================================


#ifndef TAO_ENDPOINTPOLICY_H
#define TAO_ENDPOINTPOLICY_H

#include /**/ "ace/pre.h"

#include "tao/EndpointPolicy/EndpointPolicy_Export.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "tao/PI/PI.h"
#include "tao/Versioned_Namespace.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

class TAO_EndpointPolicy_Export TAO_EndpointPolicy_Initializer
  : public ACE_Service_Object
{
public:
  /// Used to force the initialization of the ORB code.
  static int static_init (void);

  /// Initialize the Endpoint Policy loader hooks.
  virtual int init (int argc, ACE_TCHAR* []);
};

static int
TAO_Requires_EndpointPolicy_Initializer = TAO_EndpointPolicy_Initializer::static_init ();



ACE_STATIC_SVC_DECLARE_EXPORT (TAO_EndpointPolicy, TAO_EndpointPolicy_Initializer)
ACE_FACTORY_DECLARE (TAO_EndpointPolicy, TAO_EndpointPolicy_Initializer)

TAO_END_VERSIONED_NAMESPACE_DECL
#include /**/ "ace/post.h"

#define TAO_ENDPOINTPOLICY_SAFE_INCLUDE
#include "tao/EndpointPolicy/EndpointPolicyC.h"
#include "tao/EndpointPolicy/EndpointPolicyA.h"
#include "tao/IOPC.h"
#include "tao/AnyTypeCode/Any.h"
#undef TAO_ENDPOINTPOLICY_SAFE_INCLUDE

#endif /* TAO_ENDPOINTPOLICY_H */
